documentFactory.XmlDocumentStream

|  | ## Cheshire3 Object Model: Class XmlDocumentStream

Module documentFactory :: Class XmlDocumentStream

## Class XmlDocumentStream
source code

Object Tree:

    BaseDocumentStream --+
                         |
                        XmlDocumentStream

Instance Methods

__init__(self, session, stream, format, schema="", codec="", factory=None)
find_documents(self, session, cache=0)
Inherited from `BaseDocumentStream`: `fetch_document`, `open_stream`

Class Variables

start |
endtag |
Inherited from `BaseDocumentStream`: `codec`, `documents`, `factory`, `filterRe`, `format`, `length`, `locations`, `schema`, `stream`, `streamLocation`

Method Details

### __init__(self, session, stream, format, schema="", codec="", factory=None) (Constructor) | source code
Overrides: BaseDocumentStream.__init__

### find_documents(self, session, cache=0) | source code

Class Variable Details

    ### start Value:
        None

    ### endtag Value:
        ''